.. paidiverpy documentation master file, created by
   sphinx-quickstart on Wed May  5 22:45:36 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Paidiverpy package documentation
====================

**Paidiverpy** is a Python package designed to create pipelines for preprocessing image data for biodiversity analysis.

|lifecycle|

|License|

.. admonition:: Note

  This package is still in active development, and frequent updates and changes are expected. The API and features may evolve as we continue improving it.

  Comprehensive documentation is forthcoming.


Documentation
-------------

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    why
    install
    usage
    package_organisation
    configuration_file
    images_metadata
    example_data
    gallery

.. toctree::
    :maxdepth: 2
    :caption: User Guide

    user-guide/guide1/index
    user-guide/guide2/index
    user-guide/guide3/index
    user-guide/guide4/index
    performances
    custom_algorithms

.. toctree::
    :maxdepth: 2
    :caption: Help & Reference

    contributing
    api


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`



.. |Documentation| image:: https://img.shields.io/static/v1?label=&message=Read%20the%20documentation&color=blue&logo=read-the-docs&logoColor=white
   :target: https://argopy.readthedocs.io
.. |License| image:: https://img.shields.io/badge/license-Apache%202.0-blue?style=flat-square
    :target: https://www.apache.org/licenses/
.. .. |Python version| image:: https://img.shields.io/pypi/pyversions/argopy
..    :target: //pypi.org/project/argopy/
.. .. |Anaconda-Server Badge| image:: https://anaconda.org/conda-forge/argopy/badges/platforms.svg
..    :target: https://anaconda.org/conda-forge/argopy
.. |lifecycle| image:: https://img.shields.io/badge/lifecycle-stable-green.svg
   :target: https://www.tidyverse.org/lifecycle/#stable
